@@ -64,7 +64,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString &bdAddr, const QStri
     }
 
     if (service != QLatin1String("dun") && service != QLatin1String("nap")) {
-        KMessageBox::sorry(nullptr, i18n("Only 'dun' and 'nap' services are supported."));
+        KMessageBox::error(nullptr, i18n("Only 'dun' and 'nap' services are supported."));
         return;
     }
 
@@ -89,6 +89,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString &bdAddr, const QStri
 #if WITH_MODEMMANAGER_SUPPORT
     else if (service == QLatin1String("dun")) {
         QPointer<MobileConnectionWizard> mobileConnectionWizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Bluetooth);
+        mobileConnectionWizard->setAttribute(Qt::WA_DeleteOnClose);
         connect(mobileConnectionWizard.data(), &MobileConnectionWizard::accepted, [bdAddr, connectionName, mobileConnectionWizard]() {
             if (mobileConnectionWizard->getError() == MobileProviders::Success) {
                 qCDebug(PLASMA_NM_KDED_LOG) << "Mobile broadband wizard finished:" << mobileConnectionWizard->type() << mobileConnectionWizard->args();
@@ -119,11 +120,6 @@ void BluetoothMonitor::addBluetoothConnection(const QString &bdAddr, const QStri
                 }
             }
         });
-        connect(mobileConnectionWizard.data(), &MobileConnectionWizard::finished, [mobileConnectionWizard]() {
-            if (mobileConnectionWizard) {
-                mobileConnectionWizard->deleteLater();
-            }
-        });
         mobileConnectionWizard->setModal(true);
         mobileConnectionWizard->show();
     }
